# Whip validator report

Date: 2018-08-21 17:57

## Summary

Total rows: 5

#### Unknown fields:

(these fields are described in the whip specifications, but are missing in the data)

#### Unspecified fields:

(these fields exist in data, but have no whip specification):

## Specifications

Field | Specification | Constraint | Passed records |
--- | --- | --- | --- | ---
| allowed | BE, NL | 4 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | BA | unallowed value BA | 1 | 1
| empty | False | 5 |
| dateformat | %Y-%m-%d | 5 |
| empty | False | 5 |
| maxdate | 2018-12-31 | 5 |
| mindate | 2016-01-01 | 4 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | 1018-01-08 | date '1018-01-08' is before min limit '2016-01-01' | 1 | 5
| empty | False | 5 |
| max | 100 | 4 |
Value issue samples:
| Data value | Message | # Rows failed | First presence row index
--- | --- | --- | --- | ---
1 | 3300 | max value is 100 | 1 | 3
| min | 1 | 5 |
| numberformat | x | 5 |